# errors for Mirador client
# @author nickjacob (nick@mirador.im)
from api import *
